@@ -8,6 +8,7 @@ from clarifai.client.lister import Lister
 from clarifai.client.model import Model
 from clarifai.client.module import Module
 from clarifai.client.pipeline import Pipeline
+from clarifai.client.pipeline_step import PipelineStep
 from clarifai.client.search import Search
 from clarifai.client.user import User
 from clarifai.client.workflow import Workflow
@@ -20,6 +21,7 @@ __all__ = [
     'Model',
     'Workflow',
     'Pipeline',
+    'PipelineStep',
     'Module',
     'Lister',
     'Dataset',
