@@ -445,7 +445,9 @@ class Model(Lister, BaseClient):
         response = self._grpc_request(self.STUB.PostModelVersions, request)
         if response.status.code != status_code_pb2.SUCCESS:
             raise Exception(response.status)
-        self.logger.info("\nModel Version created\n%s", response.status)
+        self.logger.info(
+            f"Model Version with ID '{response.model.model_version.id}' is created:\n{response.status}"
+        )
 
         kwargs.update({'app_id': self.app_id, 'user_id': self.user_id})
         dict_response = MessageToDict(response, preserving_proto_field_name=True)
@@ -2099,3 +2101,33 @@ class Model(Lister, BaseClient):
             model_id=self.id,
             model_version=dict(id=response.model.model_version.id),
         )
+
+    def patch_version(self, version_id: str, **kwargs) -> 'Model':
+        """Patch the model version with the given version ID.
+        Args:
+            version_id (str): The version ID to patch.
+            **kwargs: Additional keyword arguments to update the model version.
+        Example:
+            >>> from clarifai.client.model import Model
+            >>> model = Model(model_id='model_id', user_id='user_id', app_id='app_id')
+            >>> model.patch_version(version_id='version_id', method_signatures=signatures)
+        """
+        request = service_pb2.PatchModelVersionsRequest(
+            user_app_id=self.user_app_id,
+            model_id=self.id,
+            action='merge',
+            model_versions=[
+                resources_pb2.ModelVersion(
+                    id=version_id,
+                    **kwargs,
+                )
+            ],
+        )
+        response = self._grpc_request(self.STUB.PatchModelVersions, request)
+        if response.status.code != status_code_pb2.SUCCESS:
+            raise Exception(response.status)
+        return Model.from_auth_helper(
+            auth=self.auth_helper,
+            model_id=self.id,
+            model_version=dict(id=version_id),
+        )
